@@ -1382,6 +1382,10 @@ create_and_set_up_tree_view (FMListView *view)
 							     NULL);
 			
 			cell = gtk_cell_renderer_text_new ();
+                        g_object_set (cell,
+                                      "ellipsize", PANGO_ELLIPSIZE_END,
+                                      "width-chars", 16,
+                                      NULL);
 			view->details->file_name_cell = (GtkCellRendererText *)cell;
 			g_signal_connect (cell, "edited", G_CALLBACK (cell_renderer_edited), view);
 			g_signal_connect (cell, "editing-canceled", G_CALLBACK (cell_renderer_editing_canceled), view);
@@ -2504,11 +2508,9 @@ fm_list_view_emblems_changed (FMDirectoryView *directory_view)
 {
 	g_assert (FM_IS_LIST_VIEW (directory_view));
 
-#if GNOME2_CONVERSION_COMPLETE
 	/* FIXME: This needs to update the emblems of the icons, since
 	 * relative emblems may have changed.
 	 */
-#endif
 }
 
 static char *
