@@ -218,7 +218,7 @@ realize (GtkWidget *widget)
 
 	/* Make sure we get keyboard events */
 	gtk_widget_set_events (widget, gtk_widget_get_events (widget) 
-			      | GDK_KEY_PRESS_MASK | GDK_KEY_PRESS_MASK);
+			      | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 			      
 	/* Do the work of realizing. */
 	GTK_WIDGET_CLASS (parent_class)->realize (widget);
@@ -246,6 +246,12 @@ real_get_title (NautilusWindow *window)
 	return g_strdup (_("Desktop"));
 }
 
+static char *
+real_get_icon_name (NautilusWindow *window)
+{
+	return g_strdup ("gnome-fs-desktop");
+}
+
 static void
 nautilus_desktop_window_class_init (NautilusDesktopWindowClass *class)
 {
@@ -262,4 +268,7 @@ nautilus_desktop_window_class_init (NautilusDesktopWindowClass *class)
 		= real_add_current_location_to_history_list;
 	NAUTILUS_WINDOW_CLASS (class)->get_title 
 		= real_get_title;
+	NAUTILUS_WINDOW_CLASS (class)->get_icon_name
+		= real_get_icon_name;
+
 }
